/**
 * COMPILE WITH:
 * valac --pkg clutter-1.0 --pkg clutk-0.3 --pkg unity --pkg gee-1.0 --pkg dee-1.0 istress.vala
 */
namespace Stress
{  
  static Ctk.IconView tiles;
  static Ctk.ScrollView scroll;
  static int next_icon = 0;

  public static int main (string[] args)
  {
    //Ctk.init (ref args);
    Clutter.init (ref args);
    Gtk.init (ref args);
    Ctk.init_after (ref args);
  
    var stage = Clutter.Stage.get_default ();
    stage.width = 600;
    stage.height = 400;
    stage.color = Clutter.Color () { alpha = 255 };
    
    scroll = new Ctk.ScrollView ();
    stage.add_actor (scroll);
    scroll.reactive = true;
    scroll.width = 600;
    scroll.height = 400;
  
    tiles = new Ctk.IconView ();
    tiles.padding = { 12.0f, 0.0f, 0.0f, 0.0f };
    tiles.spacing = 24;
    scroll.add_actor (tiles);
    
    Timeout.add_seconds (1, load_icons);
    load_icons ();
    
    stage.show_all ();
    Clutter.main ();
    
    return 0;
  }
  
  private bool load_icons ()
  {
    var pixbufs = Unity.PixbufCache.get_default ();
  
    for (int i = 0; next_icon < ICONS.length && i < 10; i++)
    {
      string icon_name = ICONS[next_icon];
      var img = new Ctk.Image (48);
      
      img.show ();
      pixbufs.set_image_from_icon_name (img, icon_name, 48);
      tiles.add_actor (img);
      
      next_icon++;
    }
    
    /* If we're not done reschedule another batch after next frame */
    if (next_icon < ICONS.length)
      {        
        Timeout.add (1000/Clutter.get_default_frame_rate () + 5, load_icons);
      }
    
    return false;
  }
  
  /* grep Icon /usr/share/applications/desktop.en_DK.utf8.cache | sed -e 's/Icon=/"/g' -e 's/$/",/g' | sort */
  const string[] ICONS = {
    "accessories-calculator",
    "accessories-character-map",
    "accessories-dictionary",
    "accessories-text-editor",
    "accessories-text-editor",
    "airstrike.xpm",
    "alacarte",
    "anjuta",
    "applets-screenshooter",
    "application-x-executable",
    "apport",
    "baobab",
    "bluetooth",
    "boats.png",
    "bomber",
    "brasero",
    "bzr-icon-64",
    "bzr-icon-64",
    "bzr-icon-64",
    "ccsm",
    "cgoban_icon",
    "checkbox",
    "chromium-browser",
    "computer",
    "computerjanitor",
    "config-language",
    "config-users",
    "devhelp",
    "dfeet-icon",
    "distributor-logo",
    "docky",
    "drgeo_32x32.xpm",
    "empathy",
    "empathy",
    "eog",
    "etw",
    "evince",
    "evolution",
    "evolution",
    "evolution",
    "evolution",
    "file-roller",
    "firefox",
    "folder-new",
    "folder-open",
    "folder-remote",
    "folder-wine",
    "f-spot",
    "f-spot",
    "f-spot",
    "gbrainy",
    "gconf-editor",
    "gdm-setup",
    "gimp",
    "gksu-root-terminal",
    "gnome-aisleriot",
    "gnome-chess.png",
    "gnome-control-center",
    "gnome-do",
    "gnome-hearts.png",
    "gnome-iagno",
    "gnome-logo-icon-transparent",
    "gnome-mahjongg",
    "gnome-main-menu",
    "gnome-mime-application-x-deb",
    "gnome-mines",
    "gnome-nettool",
    "gnome-network-properties",
    "gnome-panel",
    "gnome-power-manager",
    "gnome-quadrapassel",
    "gnome-settings-default-applications",
    "gnome-sound-recorder",
    "gnome-sudoku",
    "gstreamer-properties",
    "gtk-recordmydesktop.png",
    "gwibber",
    "gwibber",
    "gwibber",
    "help-browser",
    "htop",
    "ibus-setup",
    "inkscape",
    "input-keyboard",
    "input-mouse",
    "jockey",
    "liferea",
    "logviewer",
    "midori",
    "monodevelop",
    "multimedia-volume-control",
    "mumble",
    "network-workgroup",
    "notification-properties",
    "numptyphysics",
    "ooo-calc",
    "ooo-draw",
    "ooo-impress",
    "ooo-math",
    "ooo-writer",
    "openjdk-6",
    "openjdk-6",
    "openjdk-6",
    "orca",
    "palimpsest",
    "pitivi",
    "preferences-desktop-accessibility",
    "preferences-desktop-display",
    "preferences-desktop-font",
    "preferences-desktop-keyboard",
    "preferences-desktop-keyboard-shortcuts",
    "preferences-desktop-remote-desktop",
    "preferences-desktop-screensaver",
    "preferences-desktop-theme",
    "preferences-desktop-theme",
    "preferences-system-network",
    "preferences-system-windows",
    "printer",
    "printer",
    "rhythmbox",
    "rhythmbox",
    "scanner",
    "screenruler",
    "seahorse",
    "session-properties",
    "shotwell",
    "shotwell",
    "softwarecenter",
    "software-properties",
    "sopwith.png",
    "synaptic",
    "synaptic",
    "synfig_icon",
    "sysprof",
    "system-file-manager",
    "system-file-manager",
    "system-file-manager",
    "system-file-manager",
    "system-search",
    "time-admin",
    "tomboy",
    "totem",
    "transmission",
    "tsclient",
    "ubuntuone",
    "update-manager",
    "usb-creator-gtk",
    "user-home",
    "user-info",
    "/usr/share/byobu/pixmaps/byobu.svg",
    "/usr/share/icons/hicolor/48x48/apps/gufw_menu.png",
    "/usr/share/icons/hicolor/scalable/apps/onboard.svg",
    "/usr/share/icons/hicolor/scalable/apps/onboard.svg",
    "/usr/share/pixmaps/hplj1020_icon.png",
    "/usr/share/pixmaps/python2.6.xpm",
    "utilities-system-monitor",
    "utilities-terminal",
    "vinagre",
    "vinagre",
    "vodovod.xpm",
    "wine",
    "wine-notepad",
    "wine-uninstaller",
    "wine-winecfg",
    "xbill",
    "xchat-gnome",
    "xscorch",
    "xwelltris"
  };
}
